@@ -95,6 +95,47 @@ class ProductFees(Client):
         kwargs.update(self._create_body(price, shipping_price, currency, is_fba, asin, points, marketplace_id, optional_fulfillment_program))
         return self._request(fill_query_params(kwargs.pop('path'), asin), data=kwargs)
 
+
+    def get_product_fees_estimate(self, estimate_requests: list[dict]) -> ApiResponse:
+        """
+        get_product_fees_estimate(self, estimate_requests: list[dict]) -> ApiResponse
+
+        Return fees for multiple products
+
+        Examples:
+            literal blocks::
+
+                ProductFees().get_product_fees_estimate(
+                        [
+                            dict(id_type='ASIN', id_value='B012345678', price=100),
+                            dict(id_type='ASIN', id_value='B012345678', price=50, is_fba=True),
+                        ]
+                    )
+
+
+        Args:
+            estimate_requests: list of dict where the allowed keys are :
+                id_type: str | ASIN or SellerSKU
+                id_value: str
+                price:
+                currency:
+                shipping_price:
+                is_fba:
+                points:
+                marketplace_id: str | Defaults to self.marketplace_id
+                optional_fulfillment_program:
+        """
+        data = [
+            dict(
+                IdType = er.pop('id_type'),
+                IdValue = er.pop('id_value'),
+                **self._create_body(**er)
+            )
+            for er in estimate_requests
+        ]
+        return self._request('/products/fees/v0/feesEstimate', data=data, params=dict(method='POST'), wrap_list=True)
+
+
     def _create_body(self, price, shipping_price=None, currency='USD', is_fba=False, identifier=None,
                      points: dict = None, marketplace_id: str = None, optional_fulfillment_program: str=None):
         """
@@ -130,3 +171,10 @@ class ProductFees(Client):
                 'MarketplaceId': marketplace_id or self.marketplace_id
             }
         }
+
+
+    def _add_marketplaces(self, data):
+        # MarketplaceID is a property of the body's FeesEstimateRequest for this section, and does
+        # not need to be added. Additionally, Client._add_marketplaces will fail as it assumes
+        # data is a dict, which is not the case for get_product_fees_estimate.
+        pass
